/* Generated by ./src/xlat/gen.sh from ./src/xlat/ifstats_xstats_bridge_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BRIDGE_XSTATS_UNSPEC) == (0), "BRIDGE_XSTATS_UNSPEC != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BRIDGE_XSTATS_VLAN) == (1), "BRIDGE_XSTATS_VLAN != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BRIDGE_XSTATS_MCAST) == (2), "BRIDGE_XSTATS_MCAST != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BRIDGE_XSTATS_PAD) == (3), "BRIDGE_XSTATS_PAD != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BRIDGE_XSTATS_STP) == (4), "BRIDGE_XSTATS_STP != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat ifstats_xstats_bridge_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data ifstats_xstats_bridge_attrs_xdata[] = {
 [BRIDGE_XSTATS_UNSPEC] = XLAT(BRIDGE_XSTATS_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (BRIDGE_XSTATS_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(BRIDGE_XSTATS_UNSPEC)
 [BRIDGE_XSTATS_VLAN] = XLAT(BRIDGE_XSTATS_VLAN),
 #define XLAT_VAL_1 ((unsigned) (BRIDGE_XSTATS_VLAN))
 #define XLAT_STR_1 STRINGIFY(BRIDGE_XSTATS_VLAN)
 [BRIDGE_XSTATS_MCAST] = XLAT(BRIDGE_XSTATS_MCAST),
 #define XLAT_VAL_2 ((unsigned) (BRIDGE_XSTATS_MCAST))
 #define XLAT_STR_2 STRINGIFY(BRIDGE_XSTATS_MCAST)
 [BRIDGE_XSTATS_PAD] = XLAT(BRIDGE_XSTATS_PAD),
 #define XLAT_VAL_3 ((unsigned) (BRIDGE_XSTATS_PAD))
 #define XLAT_STR_3 STRINGIFY(BRIDGE_XSTATS_PAD)
 [BRIDGE_XSTATS_STP] = XLAT(BRIDGE_XSTATS_STP),
 #define XLAT_VAL_4 ((unsigned) (BRIDGE_XSTATS_STP))
 #define XLAT_STR_4 STRINGIFY(BRIDGE_XSTATS_STP)
};
static
const struct xlat ifstats_xstats_bridge_attrs[1] = { {
 .data = ifstats_xstats_bridge_attrs_xdata,
 .size = ARRAY_SIZE(ifstats_xstats_bridge_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
