/* Generated by ./src/xlat/gen.sh from ./src/xlat/sg_io_dxfer_direction.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat sg_io_dxfer_direction[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sg_io_dxfer_direction_xdata[] = {
#if defined(SG_DXFER_NONE) || (defined(HAVE_DECL_SG_DXFER_NONE) && HAVE_DECL_SG_DXFER_NONE)
  XLAT(SG_DXFER_NONE),
 #define XLAT_VAL_0 ((unsigned) (SG_DXFER_NONE))
 #define XLAT_STR_0 STRINGIFY(SG_DXFER_NONE)
#endif
#if defined(SG_DXFER_TO_DEV) || (defined(HAVE_DECL_SG_DXFER_TO_DEV) && HAVE_DECL_SG_DXFER_TO_DEV)
  XLAT(SG_DXFER_TO_DEV),
 #define XLAT_VAL_1 ((unsigned) (SG_DXFER_TO_DEV))
 #define XLAT_STR_1 STRINGIFY(SG_DXFER_TO_DEV)
#endif
#if defined(SG_DXFER_FROM_DEV) || (defined(HAVE_DECL_SG_DXFER_FROM_DEV) && HAVE_DECL_SG_DXFER_FROM_DEV)
  XLAT(SG_DXFER_FROM_DEV),
 #define XLAT_VAL_2 ((unsigned) (SG_DXFER_FROM_DEV))
 #define XLAT_STR_2 STRINGIFY(SG_DXFER_FROM_DEV)
#endif
#if defined(SG_DXFER_TO_FROM_DEV) || (defined(HAVE_DECL_SG_DXFER_TO_FROM_DEV) && HAVE_DECL_SG_DXFER_TO_FROM_DEV)
  XLAT(SG_DXFER_TO_FROM_DEV),
 #define XLAT_VAL_3 ((unsigned) (SG_DXFER_TO_FROM_DEV))
 #define XLAT_STR_3 STRINGIFY(SG_DXFER_TO_FROM_DEV)
#endif
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat sg_io_dxfer_direction[1] = { {
 .data = sg_io_dxfer_direction_xdata,
 .size = ARRAY_SIZE(sg_io_dxfer_direction_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
