/* Generated by ./src/xlat/gen.sh from ./src/xlat/perf_event_read_format.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(PERF_FORMAT_TOTAL_TIME_ENABLED) || (defined(HAVE_DECL_PERF_FORMAT_TOTAL_TIME_ENABLED) && HAVE_DECL_PERF_FORMAT_TOTAL_TIME_ENABLED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PERF_FORMAT_TOTAL_TIME_ENABLED) == (1 << 0), "PERF_FORMAT_TOTAL_TIME_ENABLED != 1 << 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PERF_FORMAT_TOTAL_TIME_ENABLED 1 << 0
#endif
#if defined(PERF_FORMAT_TOTAL_TIME_RUNNING) || (defined(HAVE_DECL_PERF_FORMAT_TOTAL_TIME_RUNNING) && HAVE_DECL_PERF_FORMAT_TOTAL_TIME_RUNNING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PERF_FORMAT_TOTAL_TIME_RUNNING) == (1 << 1), "PERF_FORMAT_TOTAL_TIME_RUNNING != 1 << 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PERF_FORMAT_TOTAL_TIME_RUNNING 1 << 1
#endif
#if defined(PERF_FORMAT_ID) || (defined(HAVE_DECL_PERF_FORMAT_ID) && HAVE_DECL_PERF_FORMAT_ID)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PERF_FORMAT_ID) == (1 << 2), "PERF_FORMAT_ID != 1 << 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PERF_FORMAT_ID 1 << 2
#endif
#if defined(PERF_FORMAT_GROUP) || (defined(HAVE_DECL_PERF_FORMAT_GROUP) && HAVE_DECL_PERF_FORMAT_GROUP)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PERF_FORMAT_GROUP) == (1 << 3), "PERF_FORMAT_GROUP != 1 << 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PERF_FORMAT_GROUP 1 << 3
#endif
#if defined(PERF_FORMAT_LOST) || (defined(HAVE_DECL_PERF_FORMAT_LOST) && HAVE_DECL_PERF_FORMAT_LOST)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PERF_FORMAT_LOST) == (1 << 4), "PERF_FORMAT_LOST != 1 << 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PERF_FORMAT_LOST 1 << 4
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat perf_event_read_format in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data perf_event_read_format_xdata[] = {
 XLAT(PERF_FORMAT_TOTAL_TIME_ENABLED),
 #define XLAT_VAL_0 ((unsigned) (PERF_FORMAT_TOTAL_TIME_ENABLED))
 #define XLAT_STR_0 STRINGIFY(PERF_FORMAT_TOTAL_TIME_ENABLED)
 XLAT(PERF_FORMAT_TOTAL_TIME_RUNNING),
 #define XLAT_VAL_1 ((unsigned) (PERF_FORMAT_TOTAL_TIME_RUNNING))
 #define XLAT_STR_1 STRINGIFY(PERF_FORMAT_TOTAL_TIME_RUNNING)
 XLAT(PERF_FORMAT_ID),
 #define XLAT_VAL_2 ((unsigned) (PERF_FORMAT_ID))
 #define XLAT_STR_2 STRINGIFY(PERF_FORMAT_ID)
 XLAT(PERF_FORMAT_GROUP),
 #define XLAT_VAL_3 ((unsigned) (PERF_FORMAT_GROUP))
 #define XLAT_STR_3 STRINGIFY(PERF_FORMAT_GROUP)
 XLAT(PERF_FORMAT_LOST),
 #define XLAT_VAL_4 ((unsigned) (PERF_FORMAT_LOST))
 #define XLAT_STR_4 STRINGIFY(PERF_FORMAT_LOST)
};
static
const struct xlat perf_event_read_format[1] = { {
 .data = perf_event_read_format_xdata,
 .size = ARRAY_SIZE(perf_event_read_format_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
