/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_ifla_info_data_tun_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_ifla_info_data_tun_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_ifla_info_data_tun_attrs_xdata[] = {
 [IFLA_TUN_UNSPEC] = XLAT(IFLA_TUN_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (IFLA_TUN_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(IFLA_TUN_UNSPEC)
 [IFLA_TUN_OWNER] = XLAT(IFLA_TUN_OWNER),
 #define XLAT_VAL_1 ((unsigned) (IFLA_TUN_OWNER))
 #define XLAT_STR_1 STRINGIFY(IFLA_TUN_OWNER)
 [IFLA_TUN_GROUP] = XLAT(IFLA_TUN_GROUP),
 #define XLAT_VAL_2 ((unsigned) (IFLA_TUN_GROUP))
 #define XLAT_STR_2 STRINGIFY(IFLA_TUN_GROUP)
 [IFLA_TUN_TYPE] = XLAT(IFLA_TUN_TYPE),
 #define XLAT_VAL_3 ((unsigned) (IFLA_TUN_TYPE))
 #define XLAT_STR_3 STRINGIFY(IFLA_TUN_TYPE)
 [IFLA_TUN_PI] = XLAT(IFLA_TUN_PI),
 #define XLAT_VAL_4 ((unsigned) (IFLA_TUN_PI))
 #define XLAT_STR_4 STRINGIFY(IFLA_TUN_PI)
 [IFLA_TUN_VNET_HDR] = XLAT(IFLA_TUN_VNET_HDR),
 #define XLAT_VAL_5 ((unsigned) (IFLA_TUN_VNET_HDR))
 #define XLAT_STR_5 STRINGIFY(IFLA_TUN_VNET_HDR)
 [IFLA_TUN_PERSIST] = XLAT(IFLA_TUN_PERSIST),
 #define XLAT_VAL_6 ((unsigned) (IFLA_TUN_PERSIST))
 #define XLAT_STR_6 STRINGIFY(IFLA_TUN_PERSIST)
 [IFLA_TUN_MULTI_QUEUE] = XLAT(IFLA_TUN_MULTI_QUEUE),
 #define XLAT_VAL_7 ((unsigned) (IFLA_TUN_MULTI_QUEUE))
 #define XLAT_STR_7 STRINGIFY(IFLA_TUN_MULTI_QUEUE)
 [IFLA_TUN_NUM_QUEUES] = XLAT(IFLA_TUN_NUM_QUEUES),
 #define XLAT_VAL_8 ((unsigned) (IFLA_TUN_NUM_QUEUES))
 #define XLAT_STR_8 STRINGIFY(IFLA_TUN_NUM_QUEUES)
 [IFLA_TUN_NUM_DISABLED_QUEUES] = XLAT(IFLA_TUN_NUM_DISABLED_QUEUES),
 #define XLAT_VAL_9 ((unsigned) (IFLA_TUN_NUM_DISABLED_QUEUES))
 #define XLAT_STR_9 STRINGIFY(IFLA_TUN_NUM_DISABLED_QUEUES)
};
static
const struct xlat rtnl_ifla_info_data_tun_attrs[1] = { {
 .data = rtnl_ifla_info_data_tun_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_ifla_info_data_tun_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
