/* Generated by ./src/xlat/gen.sh from ./src/xlat/ifstats_xstats_bridge_mcast_indices.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BR_MCAST_DIR_RX) == (0), "BR_MCAST_DIR_RX != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BR_MCAST_DIR_TX) == (1), "BR_MCAST_DIR_TX != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat ifstats_xstats_bridge_mcast_indices in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data ifstats_xstats_bridge_mcast_indices_xdata[] = {
 [BR_MCAST_DIR_RX] = XLAT(BR_MCAST_DIR_RX),
 #define XLAT_VAL_0 ((unsigned) (BR_MCAST_DIR_RX))
 #define XLAT_STR_0 STRINGIFY(BR_MCAST_DIR_RX)
 [BR_MCAST_DIR_TX] = XLAT(BR_MCAST_DIR_TX),
 #define XLAT_VAL_1 ((unsigned) (BR_MCAST_DIR_TX))
 #define XLAT_STR_1 STRINGIFY(BR_MCAST_DIR_TX)
};
static
const struct xlat ifstats_xstats_bridge_mcast_indices[1] = { {
 .data = ifstats_xstats_bridge_mcast_indices_xdata,
 .size = ARRAY_SIZE(ifstats_xstats_bridge_mcast_indices_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
